package Peptide::DictionaryScientific;
# Peptide::DictionaryScientific - scientific dictionary (words, abbreviations, software names, etc)
# Some gene symbols are included here as well, because they were not automatically obtained otherwise. Perhaps they are typos, deprecated names, or not very frequently used. Example: VEGFRI.

sub words {
    <<_WORDS_; # do not use a word that may occur below as here doc delimiter!

AANAT
AAVPS
ACTHA
ACTHMSH
ADDRESSED
ADSAP
ALVACHIV
AMART
AMINE
ANIMAL
ANSYS
ANTGIP
ANTIHYPERTENSIVE
ANTSDPX
APCPE
ARVCF
ASLVA
ASMLPD
ATLAS
ATTEMPTS
CALCI
CALLA
CAMKII
CAMKIV
CAMPATH
CAPAN
CAPAP
CAPCP
CARTLI
CCMSH
CENPA
CEREVISIAE
CGRPI
CGRPIR
CGRPLI
CHLPEP
CIITA
CLEAR
CLIPA
CNPRC
CPMAS
CRAMP
CTEPH
DADLE
DAMCK
DEAPAEETIII
DELFIA
DFFRY
DHEAS
DIANA
DICERLIKE
DIPPH
DITCCPG
DLPFC
DMAEMA
DMSAV
DMTMM
DNA
DPDPE
DPFGSE
DPPCDPPS
DPPCPG
DPPIV
DPPTE
DRAWS
DSLET
DSM
DSRCT
DTPA
DTPAD
DTPAL
DYANA
EDANS
EDDAHYNIC
EGFP
EGTA
ELISA
EMRSA
ESEEM
ESPEL
ETSHR
EXAFS
FAIMS
FAIMSMS
FDG
FFDGPET
FINDH
FITC
FPLC
FRET
FREYER
FSIVGTT
FTICR
FTICRMS
FTMSECD
GALPHA
GCSFR
GGHSL
GHRHRP
GLAST
HAART
HCHWAD
HEART
HERVH
HGPRT
HGPRTGMP
HGPRTIMP
HILIC
HILICCEC
HILICCEX
HILIXCEX
HIVPR
HMWPE
HPGPC
HPLC
HPSEC
HRMAS
HSCIE
HSQC
HTG
HTTLPR
HYNI
HYNIC
IAEDANS
ICATL
ICPMS
IDEIA
IMPALA
INADL
INSENSITIVE
IPALISA
IPEDF
IPMC
IPMN
IPTG
IRESCAT
IRMPD
IRRAS
ITSST
KDELHEL
KDR
KLH
LAMAN
LC
LIGHT
LINCL
LINCS
LLCPK
LMLCK
LMVEC
LNAME
LNMMA
LPS
LSDYNA
LSIMS
LTKIR
MAGEC
MALDI
MAMVE
MAPKKKK
MART
MARTENS
MASPIC
MEDLINE
MELAN
MELANA
MFC
MHCPEP
MHLADM
MIACE
MIANS
MIDAS
MIDGE
MLCKI
MLPA
MPIDT
MS
MVIIA
MVIIAMVIIC
MVIIC
MVSMC
NFMP
NHERF
NIDDM
NILIACD
NMDAR
NMR
NMSCC
NSAID
NSAIDS
NSCLC
PADRE
PAIRC
PALES
PAMAM
PAMAMPEG
PANSS
PCR
PCTFE
PDAPP
PDGFR
PECAM
PEI
PEPSEARCH
PERLA
PET
PFACE
PHENYX
PISEMA
PITIM
PLGA
PMIRRAS
PRELP
PRIME
PRMRT
PRRSV
PVIIA
QSAR
QSTAR
RELISH
RESID
REVIEW
RFLP
RHAMM
RIACT
RNAIII
RNFNN
RTPCR
SALSA
SAXS
SCCHN
SDSPAGE
SEEPLY
SELECT
SELEX
SERCA
SHERENGA
SHRSP
SIGNIFICANCE
SILAC
SISCAPA
SMLCK
SNAFL
SPITC
SSIMS
SSNAP
SSRI
STANA
STEAP
SVRMHC
SWCNT
SYFPEITHI
TAMRA
TCRAV
TETATATE
TFMSA
THAPDAHC
THRGP
TMADPH
TMHMM
VDACI
VEGFII
VEGFKDR
VEGFRI
VEGFRII
VIPRS
VISNA
VLEIDEN
VLFXA
VMAXK
WAXS
XNPRC
XPDAP
YNHCH


PTLPD
ADPKD
HTLVIII
HIV
PSII
LHCII
CSF
LCDIIIA
NPIIIP
VIIAHF
DSM
IIVGTT
IIEER
MAPK
MEK
MOS
RSK
PNIIIP
CGIIIA
TFIIK
FCGRIIA
DADTIIR
FVIIISQ
GKLF
KLF4




_WORDS_
}

1;
